# 扩展SQLAlchemy
SQLAlchemy 原始 使用起来总是有些不方便，该项目对其进行了部分封装为两个类：
DbOperations和DbPagedOperations 以方便业务使用；


# (SQLALchemy Demo)[https://github.com/eastossifrage/sql_to_sqlalchemy/]

# 历史记录
0.0.1 初始版本
0.0.2 修复了部分Bug
0.0.3 封装JOIN 查询


https://yifei.me/note/2652
https://www.osgeo.cn/sqlalchemy/